Error

Enum Error 

pub enum Error {
Show 17 variants BadSignature, Encoding(String), IllegalArgument(String), NoSupportedHashAlgorithm, NotFound, Opaque(String), Programming(String), TargetUnavailable, UnknownHashAlgorithm(String), UnknownKeyType(String), VerificationFailure(String), LinkGatheringError(String), PAEParseFailed(String), RunLibError(String), AttestationFormatDismatch(String, String), StringConvertFailed(String), ArtifactRuleError(String),
}
Error type for all in-toto related errors.

Variants



BadSignature

The metadata had a bad signature.



Encoding(String)

There was a problem encoding or decoding.



IllegalArgument(String)

An illegal argument was passed into a function.



NoSupportedHashAlgorithm

There were no available hash algorithms.



NotFound

The metadata or target was not found.



Opaque(String)

Opaque error type, to be interpreted similar to HTTP 500. Something went wrong, and you may or may not be able to do anything about it.



Programming(String)

There was a library internal error. These errors are ALWAYS bugs and should be reported.



TargetUnavailable

The target is unavailable. This may mean it is either not in the metadata or the metadata chain to the target cannot be fully verified.



UnknownHashAlgorithm(String)

There is no known or available hash algorithm.



UnknownKeyType(String)

There is no known or available key type.



VerificationFailure(String)

The metadata or target failed to verify.



LinkGatheringError(String)



PAEParseFailed(String)



RunLibError(String)



AttestationFormatDismatch(String, String)



StringConvertFailed(String)



ArtifactRuleError(String)

Implementations

Source

impl Error

pub fn from_io(err: &Error, path: &Path) -> Error

Helper to include the path that causd the error for FS I/O errors.